"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Application = void 0;
const container_1 = require("@quarter/container");
const support_1 = require("@quarter/support");
class Application extends container_1.Container {
    constructor(config) {
        super();
        this.booted = false;
        this.providers = new Map();
        this.provide("app", this);
        this.provide("config", new support_1.Entity(config));
        this.provide("events", new support_1.Dispatcher());
        this.registerConfigProviders();
    }
    get config() {
        return this.make("config");
    }
    get events() {
        return this.make("events");
    }
    boot() {
        if (!this.booted) {
            this.providers.forEach((provider) => provider.boot());
            this.booted = true;
        }
    }
    register(Provider) {
        if (this.providers.has(Provider)) {
            return this.providers.get(Provider);
        }
        const provider = new Provider(this);
        this.providers.set(Provider, provider);
        provider.register();
        if (this.booted) {
            provider.boot();
        }
        return provider;
    }
    registerConfigProviders() {
        const providers = this.config.get("app.providers", []);
        providers.forEach((Provider) => this.register(Provider));
    }
}
exports.Application = Application;
//# sourceMappingURL=Application.js.map