"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Project = void 0;
const support_1 = require("@quarter/support");
const Application_1 = require("./Application");
const path_1 = require("path");
class Project extends Application_1.Application {
    constructor(path, config) {
        super(config);
        this.provide("filesystem", new support_1.Filesystem(path));
        this.provide("environment", new support_1.Environment(this.filesystem));
        this.registerConfig();
        this.registerConfigProviders();
    }
    get env() {
        return this.make("environment");
    }
    get filesystem() {
        return this.make("filesystem");
    }
    appPath(path = ".") {
        const basepath = this.config.get("paths.app", "app");
        return this.basePath((0, path_1.join)(basepath, path));
    }
    basePath(path = ".") {
        return this.filesystem.resolve(path);
    }
    buildPath(path = ".") {
        const basepath = this.config.get("paths.build", "build");
        return this.basePath((0, path_1.join)(basepath, path));
    }
    configPath(path = ".") {
        const basepath = this.config.get("paths.config", "config");
        return this.basePath((0, path_1.join)(basepath, path));
    }
    publicPath(path = ".") {
        const basepath = this.config.get("paths.public", "public");
        return this.basePath((0, path_1.join)(basepath, path));
    }
    storagePath(path = ".") {
        const basepath = this.config.get("paths.storage", "storage");
        return this.basePath((0, path_1.join)(basepath, path));
    }
    registerConfig(path = this.configPath()) {
        if (this.filesystem.exists(path)) {
            const filesystem = this.filesystem.from(path);
            filesystem.files(".").forEach((file) => {
                const { name } = (0, path_1.parse)(file);
                const filepath = filesystem.resolve(file);
                const config = require(filepath).default(this);
                this.config.merge({ [name]: config });
            });
        }
    }
}
exports.Project = Project;
//# sourceMappingURL=Project.js.map